==> xueshanlinghu-1.2.3.tar.gz: xueshanlinghu-1.2.3/README.md <==
# xueshanlinghu-package
This is the GitHub repo to save the source of the install package of xueshanlinghu package. Inside this package we have so many practical functions to use for free.

### related websites of this package
MY PERSONAL OFFICIAL WEBSITE: [http://www.xueshanlinghu.com](http://www.xueshanlinghu.com)

You can download the package from PyPI:
[https://pypi.python.org/pypi/xueshanlinghu](https://pypi.python.org/pypi/xueshanlinghu)

You can download the package from GitHub:
[https://github.com/xueshanlinghu/xueshanlinghu-package](https://github.com/xueshanlinghu/xueshanlinghu-package)

### install
Simply use this package in your computer(please make sure that you have installed pip in your python):

    pip install xueshanlinghu

Using this command can install the xueshanlinghu package from the Internet.

### download from PyPI or GitHub
If you can't do that you can go to the website above to download.
Then if you download from GitHub(that would be a zip file) or PyPI(that would be a tar.gz file), all you should do is to unzip it, then using CMD to come into the folder, type this command to setup:

    python setup.py install

Then the pacakage of xueshanlinghu will be in your computer.

### uninstall
If you don't want to use this package anymore, you can use this command to uninstall from your computer:

    pip uninstall xueshanlinghu

### check outdated
You can use this command to check which packages are outdated:

    pip list --outdated

### upgrade the package
If you want to upload the version of this package, you can use this command:

    pip install --upgrade xueshanlinghu

### how to use this package
After installing this package, how to use the functionsin it?
Now inside the package we have these to use:
["math"]

Then you can import this package using this command(for example, you want to use math package):

    import xueshanlinghu.math
    import xueshanlinghu.math as math
    from xueshanlinghu.math import *
    from xueshanlinghu.math import sum
    ...

==> xueshanlinghu-1.2.4.tar.gz: xueshanlinghu-1.2.4/README.md <==
# xueshanlinghu-package
This is the GitHub repo to save the source of the install package of xueshanlinghu package. Inside this package we have so many practical functions to use for free.

### Related websites of this package
MY PERSONAL OFFICIAL WEBSITE: [http://www.xueshanlinghu.com](http://www.xueshanlinghu.com)

You can download the package from PyPI:
[https://pypi.python.org/pypi/xueshanlinghu](https://pypi.python.org/pypi/xueshanlinghu)

You can download the package from GitHub:
[https://github.com/xueshanlinghu/xueshanlinghu-package](https://github.com/xueshanlinghu/xueshanlinghu-package)

### Install
Simply use this package in your computer(please make sure that you have installed pip in your python):

    pip install xueshanlinghu

Using this command can install the xueshanlinghu package from the Internet.

### Download from PyPI or GitHub
If you can't do that you can go to the website above to download.
Then if you download from GitHub(that would be a zip file) or PyPI(that would be a tar.gz file), all you should do is to unzip it, then using CMD to come into the folder, type this command to setup:

    python setup.py install

Then the pacakage of xueshanlinghu will be in your computer.

### Uninstall
If you don't want to use this package anymore, you can use this command to uninstall from your computer:

    pip uninstall xueshanlinghu

### Check outdated
You can use this command to check which packages are outdated:

    pip list --outdated

### Upgrade the package
If you want to upload the version of this package, you can use this command:

    pip install --upgrade xueshanlinghu

### How to use this package
After installing this package, how to use the functionsin it?
Now inside the package we have these sub-package to use:
["math"]

You can import this package using this command(for example, you want to use math package):

    import xueshanlinghu.math
    import xueshanlinghu.math as math
    from xueshanlinghu.math import *
    from xueshanlinghu.math import sum

### New ways to use this package
From version 1.2.4, we can use new ways to call these commands:

    import xueshanlinghu
    import xueshanlinghu as xs
    from xueshanlinghu import *

Then if you want to call the sub-package:

    from xueshanlinghu.math import *
    from xueshanlinghu.math import sum
